@@ -5,16 +5,74 @@ use base 'DBIx::dbMan::Extension';
 use Text::FormatTable;
 use DBI;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 1;
 
-sub IDENTIFICATION { return "000001-000005-000006"; }
+sub IDENTIFICATION { return "000001-000005-000007"; }
 
 sub preference { return 0; }
 
 sub known_actions { return [ qw/CONNECTION/ ]; }
 
+sub menu {
+	my $obj = shift;
+
+	my @menu_use = ();
+	my @menu_close = ();
+	my @menu_reopen = ();
+	my @menu_open = ();
+	my @menu_drop = ();
+
+	for (@{$obj->{-dbi}->list('active')}) {
+		my $sel = ' ';
+		$sel = '*' if $_->{name} eq $obj->{-dbi}->current;
+		push @menu_use,{ label => $sel.' '.$_->{name},
+			action => { action => 'CONNECTION', operation => 'use',
+			what => $_->{name} } };
+		push @menu_close,{ label => $_->{name},
+			action => { action => 'CONNECTION', operation => 'close',
+			what => $_->{name} } };
+		push @menu_reopen,{ label => $_->{name},
+			action => { action => 'CONNECTION', operation => 'reopen',
+			what => $_->{name} } };
+	}
+	for (@{$obj->{-dbi}->list('inactive')}) {
+		push @menu_open,{ label => $_->{name},
+			action => { action => 'CONNECTION', operation => 'open',
+			what => $_->{name} } };
+	}
+	for (@{$obj->{-dbi}->list()}) {
+		push @menu_drop,{ label => $_->{name}, submenu => [
+			{ label => 'Temporarly', action => { action => 'CONNECTION',
+				operation => 'drop', what => $_->{name} } },
+			{ label => 'Permanently', action => { action => 'CONNECTION',
+				operation => 'drop', what => $_->{name}, permanent => 1 } }
+		] };
+	}
+
+	return ( { label => '_Connection', submenu => [
+			{ label => 'Select current', preference => 100, submenu => \@menu_use },
+			{ label => 'Close', preference => 1, submenu => \@menu_close },
+			{ label => 'Reopen', preference => 2, submenu => \@menu_reopen },
+			{ label => 'Open', preference => 3, submenu => \@menu_open },
+			{ label => 'Drop', preference => -10, submenu => \@menu_drop },
+			{ label => 'Show list', preference => 50, submenu => [
+				{ label => 'All', preference => 5,
+					action => { action => 'CONNECTION', operation => 'show' } }, 
+				{ separator => 1, preference => 2 },
+				{ label => 'Active',
+					action => { action => 'CONNECTION', operation => 'show',
+					what => 'active' } }, 
+				{ label => 'Inactive',
+					action => { action => 'CONNECTION', operation => 'show',
+					what => 'inactive' } }
+			] },
+			{ separator => 1, preference => 25 },
+			{ separator => 1, preference => -1 }
+		] } );
+}
+
 sub init {
 	my $obj = shift;
 	$obj->{prompt_num} = $obj->{-interface}->register_prompt;
@@ -37,7 +95,7 @@ sub solve_open_error {
 	} elsif ($error == -4) {
 		return "Already connected to $name.\n";
 	} elsif (not $error) {
-	        return "Connection to $name established.\n";
+		return "Connection to $name established.\n";
 	}
 }
 
@@ -49,7 +107,7 @@ sub solve_close_error {
 	} elsif ($error == -2) {
 		return "Not connected to $name.\n";
 	} elsif (not $error) {
-	        return "Disconnected from $name.\n";
+		return "Disconnected from $name.\n";
 	}
 }
 
@@ -75,6 +133,7 @@ sub handle_action {
 			my $error = $obj->{-dbi}->open($action{what});
 			$action{action} = 'OUTPUT';
 			$action{output} = $obj->solve_open_error($error,$action{what});
+			$obj->{-interface}->rebuild_menu;
 		} elsif ($action{operation} eq 'reopen') {
 			my $reuse = 0;
 			$reuse = 1 if $obj->{-dbi}->current eq $action{what};
@@ -90,14 +149,17 @@ sub handle_action {
 				$error = $obj->{-dbi}->set_current($action{what});
 				$action{output} .= $obj->solve_use_error($error,$action{what});
 			}
+			$obj->{-interface}->rebuild_menu;
 		} elsif ($action{operation} eq 'close') {
 			$action{action} = 'OUTPUT';
 			my $error = $obj->{-dbi}->close($action{what});
 			$action{output} = $obj->solve_close_error($error,$action{what});
+			$obj->{-interface}->rebuild_menu;
 		} elsif ($action{operation} eq 'use') {
 			$action{action} = 'OUTPUT';
 			my $error = $obj->{-dbi}->set_current($action{what});
 			$action{output} = $obj->solve_use_error($error,$action{what});
+			$obj->{-interface}->rebuild_menu;
 		} elsif ($action{operation} eq 'show') {
 			my @list = @{$obj->{-dbi}->list($action{what})};
 			my $clist = '';
@@ -142,6 +204,7 @@ sub handle_action {
 
 					}
 				}
+				$obj->{-interface}->rebuild_menu;
 			}
 		} elsif ($action{operation} eq 'drop') {
 			$action{action} = 'NONE';
@@ -158,9 +221,9 @@ sub handle_action {
 						$action{output} .= "Can't destroy connection $action{what}.\n";
 					} elsif (not $error) {
 						$action{output} .= "Destroying permanent connection $action{what}.\n";
-
 					}
 				}
+				$obj->{-interface}->rebuild_menu;
 			}
 		}
 
