@@ -1,15 +1,13 @@
 package DBIx::dbMan::Extension::SQLResultPreprocess;
 
 use strict;
-use vars qw/$VERSION @ISA/;
-use DBIx::dbMan::Extension;
+use base 'DBIx::dbMan::Extension';
 
-$VERSION = '0.04';
-@ISA = qw/DBIx::dbMan::Extension/;
+our $VERSION = '0.05';
 
 1;
 
-sub IDENTIFICATION { return "000001-000054-000004"; }
+sub IDENTIFICATION { return "000001-000054-000005"; }
 
 sub preference { return 50; }
 
@@ -20,7 +18,7 @@ sub handle_action {
 
 	$action{processed} = 1;
 	if ($action{action} eq 'SQL_RESULT' and not $action{sql_result_preprocess} and ref $action{result} eq 'ARRAY') {
-		@$_ = map { (defined) ? join '',map { ($_ >= 32 && $_ <= 254 && $_ != 127)?chr:sprintf "<%02x>",$_; } unpack "C*") : undef } @$_ for @{$action{result}};
+		@$_ = map { (defined) ? join '',(map { ($_ >= 32 && $_ <= 254 && $_ != 127)?chr:sprintf "<%02x>",$_; } unpack "C*",$_) : undef } @$_ for @{$action{result}};
 
 		$action{sql_result_preprocess} = 1;
 		delete $action{processed};
